@@ -7,7 +7,7 @@ use warnings;
 
 use base qw( WWW::Shorten::generic );
 our @EXPORT = qw(makeashorterlink makealongerlink);
-our $VERSION = '1.74';
+our $VERSION = '1.75';
 
 use Carp;
 
@@ -156,7 +156,7 @@ And particularly thanks to all providers of these services.
 =head1 BUGS, REQUESTS, COMMENTS
 
 Please report any requests, suggestions or bugs via the system at
-L<http://rt.cpan.org/>, or email E<lt>bug-WWW-Mechanize@rt.cpan.orgE<gt>.
+L<http://rt.cpan.org/>, or email E<lt>bug-WWW-Shorten@rt.cpan.orgE<gt>.
 This makes it much easier for me to track things and thus means
 your problem is less likely to be neglected.
 
